import { Node } from '@tiptap/core';
import { wrappingInputRule } from 'prosemirror-inputrules';

const inputRegex = /^\s*([-+*])\s$/;
const BulletList = Node.create({
    name: 'bulletList',
    defaultOptions: {
        HTMLAttributes: {},
    },
    group: 'block list',
    content: 'listItem+',
    parseHTML() {
        return [
            { tag: 'ul' },
        ];
    },
    renderHTML({ HTMLAttributes }) {
        return ['ul', HTMLAttributes, 0];
    },
    addCommands() {
        return {
            /**
             * Toggle a bullet list
             */
            toggleBulletList: () => ({ commands }) => {
                return commands.toggleList('bulletList', 'listItem');
            },
        };
    },
    addKeyboardShortcuts() {
        return {
            'Mod-Shift-8': () => this.editor.commands.toggleBulletList(),
        };
    },
    addInputRules() {
        return [
            wrappingInputRule(inputRegex, this.type),
        ];
    },
});

export default BulletList;
export { inputRegex };
//# sourceMappingURL=tiptap-extension-bullet-list.esm.js.map
